@@ -211,7 +211,7 @@ void havege_destroy(       /* RETURN: none            */
          free(temp);
          }
 #ifdef ONLINE_TESTS_ENABLE
-      else if (0 != (temp=hptr->testData)) {
+      if (0 != (temp=hptr->testData)) {
          double *g = ((procShared *)temp)->G;
          hptr->testData = 0;
          if (0 != g)
